
# This file was generated by 'versioneer.py' (0.23) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2025-12-07T02:41:27+0000",
 "dirty": false,
 "error": null,
 "full-revisionid": "5a9de6cc34f45d433f9503b8a12b698497db7d4e",
 "version": "1.6.dev2549"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
